@@ -108,10 +108,18 @@ class DeviceStatInterface(Interface):
     def is_operational(self, state):
         return state == STATE.OP
     
+    @nodealiasproperty("is_not_operational", ["state"])
+    def is_not_operational(self, state):
+        return state == STATE.NOTOP
+    
     @nodealiasproperty("is_ready", ["substate"])
     def is_ready(self, substate):
         return substate == self.SUBSTATE.NOTOP_READY
     
+    @nodealiasproperty("is_not_ready", ["substate"])
+    def is_not_ready(self, substate):
+        return substate == self.SUBSTATE.NOTOP_NOTREADY
+    
     @nodealiasproperty("is_in_error", ["substate"])
     def is_in_error(self, substate):
         """ -> True is axis is sin error state:  NOP_ERROR or OP_ERROR """
@@ -346,19 +354,28 @@ class Device:
     def init(self):
         """ init the device """
         self.rpc.rpcInit.rcall()
+        return self.stat.is_ready
+        
+    def reset(self):
+        """ reset the device """
+        self.rpc.rpcReset.rcall()
+        return self.stat.is_not_ready
 
     def enable(self):
         """ enable the device """ 
         self.rpc.rpcEnable.rcall()
-
+        return self.stat.is_operational
+        
     def disable(self):
         """ disable the device """
         self.rpc.rpcDisable.rcall()
-
+        return self.stat.is_not_operational
+        
     def reset(self):
         """ reset the device """
         self.rpc.rpcReset.rcall()
-
+        return self.stat.is_not_ready
+        
     def get_error_txt(self, errcode):
         """ Get a text description of the given error code number """
         return self.ERROR.txt.get(errcode, 'UNKNOWN ERROR')
