@@ -222,7 +222,7 @@ def wait(node_or_func_list, logic="all_true", period=0.1, timeout=60, lag=0.0, d
     """ wait until a list of function return True
 
     Args:
-        node_or_func_list (iterable): an iterable of nodes of callable. 
+        node_or_func_list (iterable): an iterable of nodes of callable.  Or a single node
                     wait will wait until all node.get and callable return True (by default)
                     
         logic (str, optional): 
@@ -309,7 +309,7 @@ class Waiter:
     The only method of this object is :method:`Waiter.wait`
     
     Args:
-        node_or_func_list (iterable): an iterable of nodes of callable. 
+        node_or_func_list (iterable): an iterable of nodes or callable. Or a single node 
                     waiter.wait will wait until all node.get and callable return True (by default)
         logic (string, optional):
               "all_true"  : stop waiting when all check function return True (default)
@@ -352,7 +352,11 @@ class Waiter:
     def __init__(self, node_or_func_list, logic="all_true", period=0.1, timeout=60, data=None, stopper=lambda:None):        
         nodes = []
         functions = []
+        if not hasattr(node_or_func_list, "__iter__"): 
+            node_or_func_list = [node_or_func_list]
+        
         for f in node_or_func_list:
+            if f is None: continue
             if isinstance(f, (Node, NodeAlias)):
                 nodes.append(f)
             else:
@@ -962,44 +966,9 @@ class Measurer:
                 
                 
     Exemple:
-       
-       Take measurement of motor position after a sequence of movement. 
-       
-       class MeasureMotorPos(Measurer):
-            def __init__(self, motor, file):
-                self.motor = motor
-                self.file = file
-                self.f = None        
-                self.counter = 0 
-                
-                super(Measurer, self).__init__( [motor.stat.pos_actual, motor.stat.pos_error] )
-            
-            def init(self): 
-                self.measurements.clear()           
-                self.counter = 0    
-                self.f = open(self.file)
-                self.f.write( "#pos_target velocity pos pos_error image\n")
-               
-            def before(self, pos_vel):
-               self.motor.move_rel(*pos_vel)
-               wait( [self.motor.stat.is_standstill], lag=0.1 )
-              
-            def after(self, pos_vel, data):
-                # Do something, for instance take an image from a camera
-                time.sleep(0.2)
-                self.counter += 1 
-                img_file = "image_%03d.tiff"%self.counter
-                # image = take_image_of_my_lab_cam()
-                # save_image(image, img_file)
-                data['image'] = img_file
-            
-            def end(self):
-                pass
-                     
-                
-               
-               
     
+        :TODO: link to exemple
+        
     """
     def __init__(self, nodes, measurements=None,  data=None):    
         
